``matplotlib.mlab``
~~~~~~~~~~~~~~~~~~~
``mlab.apply_window`` and ``mlab.stride_repeat`` have been removed.

Axes3D
~~~~~~
``axes3d.unit_bbox`` has been removed; use ``Bbox.unit`` instead.

axisartist
~~~~~~~~~~
``mpl_toolkits.axisartist.grid_finder.GridFinderBase`` has been removed; use
`.GridFinder` instead.

``axisartist.axis_artist.BezierPath`` has been removed; use
`.patches.PathPatch` instead.

Returning a factor equal to None from axisartist Locators (which are **not**
the same as "standard" tick Locators), or passing a factor equal to None
to axisartist Formatters (which are **not** the same as "standard" tick
Formatters) is no longer supported. Pass a factor equal to 1 instead.

Misc
~~~~
``matplotlib.get_home`` has been removed; use standard library instead.

``matplotlib.compare_versions`` has been removed; use comparison of
``distutils.version.LooseVersion``\s instead.

``matplotlib.checkdep_ps_distiller`` has been removed.

``matplotlib.figure.AxesStack`` has been removed.

``BboxBase.is_unit`` has been removed; check the `.Bbox` extents if needed.

``Affine2DBase.matrix_from_values(...)`` has been removed; use (for example)
``Affine2D.from_values(...).get_matrix()`` instead.

``style.core.is_style_file`` and ``style.core.iter_style_files`` have been
removed.
